@@ -1929,3 +1929,142 @@ String str(CharacterProtocol *p, strsize_t size)
     return temp;
 }
 
+static const unsigned char alphabet[65] =
+    "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
+
+size_t string::b64encode(char *dest, const uint8_t *bin, size_t size, size_t dsize)
+{
+    assert(dest != NULL && bin != NULL);
+
+    size_t count = 0;
+
+    if(!dsize)
+        dsize = size * 4 / 3;
+
+    if (!dsize || !size)
+        goto end;
+
+    unsigned bits;
+
+    while(size >= 3 && dsize > 4) {
+        bits = (((unsigned)bin[0])<<16) | (((unsigned)bin[1])<<8)
+            | ((unsigned)bin[2]);
+        bin += 3;
+        size -= 3;
+        count += 3;
+        *(dest++) = alphabet[bits >> 18];
+        *(dest++) = alphabet[(bits >> 12) & 0x3f];
+        *(dest++) = alphabet[(bits >> 6) & 0x3f];
+        *(dest++) = alphabet[bits & 0x3f];
+        dsize -= 4;
+    }
+
+    if (size && dsize > 4) {
+        bits = ((unsigned)bin[0])<<16;
+        *(dest++) = alphabet[bits >> 18];
+        ++count;
+        if (size == 1) {
+            *(dest++) = alphabet[(bits >> 12) & 0x3f];
+            *(dest++) = '=';
+        }
+        else {
+            ++count;
+            bits |= ((unsigned)bin[1])<<8;
+            *(dest++) = alphabet[(bits >> 12) & 0x3f];
+            *(dest++) = alphabet[(bits >> 6) & 0x3f];
+        }
+        *(dest++) = '=';
+    }
+
+end:
+    *dest = 0;
+    return count;
+}
+
+size_t string::b64decode(uint8_t *dest, const char *src, size_t size)
+{
+    char decoder[256];
+    unsigned long bits;
+    uint8_t c;
+    unsigned i;
+    size_t count = 0;
+
+    for (i = 0; i < 256; ++i)
+        decoder[i] = 64;
+
+    for (i = 0; i < 64 ; ++i)
+        decoder[alphabet[i]] = i;
+
+    bits = 1;
+
+    while(*src) {
+        c = (uint8_t)(*(src++));
+        if (c == '=') {
+            if (bits & 0x40000) {
+                if (size < 2)
+                    break;
+                *(dest++) = (uint8_t)((bits >> 10) & 0xff);
+                *(dest++) = (uint8_t)((bits >> 2) & 0xff);
+                count += 2;
+                break;
+            }
+            if ((bits & 0x1000) && size) {
+                *(dest++) = (uint8_t)((bits >> 4) & 0xff);
+                ++count;
+            }
+            break;
+        }
+        // end on invalid chars
+        if (decoder[c] == 64)
+            break;
+        bits = (bits << 6) + decoder[c];
+        if (bits & 0x1000000) {
+            if (size < 3)
+                break;
+            *(dest++) = (uint8_t)((bits >> 16) & 0xff);
+            *(dest++) = (uint8_t)((bits >> 8) & 0xff);
+            *(dest++) = (uint8_t)((bits & 0xff));
+            bits = 1;
+            size -= 3;
+            count += 3;
+        }
+    }
+    return count;
+}
+
+#define CRC24_INIT 0xb704ceL
+#define CRC24_POLY 0x1864cfbL
+
+uint32_t string::crc24(uint8_t *binary, size_t size)
+{
+    uint32_t crc = CRC24_INIT;
+    unsigned i;
+
+    while (size--) {
+        crc ^= (*binary++) << 16;
+        for (i = 0; i < 8; i++) {
+            crc <<= 1;
+            if (crc & 0x1000000)
+                crc ^= CRC24_POLY;
+        }
+    }
+    return crc & 0xffffffL;
+}
+
+uint16_t string::crc16(uint8_t *binary, size_t size)
+{
+    uint16_t crc = 0xffff;
+    unsigned i;
+
+    while (size--) {
+        crc ^= (*binary++);
+        for (i = 0; i < 8; i++) {
+            if(crc & 1)
+                crc = (crc >> 1) ^ 0xa001;
+            else
+                crc = (crc >> 1);
+        }
+    }
+    return crc;
+}
+
